""" Distributor init file

Distributors: you can replace the contents of this file with your own custom
code to support particular distributions of SciPy.

For example, this is a good place to put any checks for hardware requirements
or BLAS/LAPACK library initialization.

The SciPy standard source distribution will not put code in this file beyond
the try-except import of `_distributor_init_local` (which is not part of a
standard source distribution), so you can safely replace this file with your
own version.
"""

try:
    from . import _distributor_init_local  # noqa: F401
except ImportError:
    pass

try:
    import contextlib
    import os
    from importlib import metadata

    # Add MKL library to DLL search path on Windows so mkl-service can find it.
    with contextlib.suppress(AttributeError, FileNotFoundError, StopIteration):
        dll = next(p for p in metadata.files("mkl") if p.match("*mkl_rt*.dll"))
        dll_dir = dll.locate().resolve().parent
        os.add_dll_directory(dll_dir)

    # Load MKL library via mkl-service so we don't have to graft it into SciPy.
    import mkl

except (ImportError, metadata.PackageNotFoundError):
    import warnings

    warnings.warn(
        "Failed to import mkl-service. Please install it or manually add the MKL "
        "library to LD_LIBRARY_PATH",
        stacklevel=2,
    )
